.. _homogenization-rs_correctors:

homogenization/rs_correctors.py
===============================

**Description**


Compute homogenized elastic coefficients for a given microstructure.


.. image:: /../doc/images/gallery/homogenization-rs_correctors.png


:download:`source code </../sfepy/examples/homogenization/rs_correctors.py>`

.. literalinclude:: /../sfepy/examples/homogenization/rs_correctors.py

